@@ -324,8 +324,10 @@ get_synonyms <- function(df, syns) {
                                  "\\1", temp[[j]][-1][k]))
         tf_opus <- grepl("ipni[.]org", temp_opus)
         if(any(tf)) {
-          temp_opus[tf_opus] <- gsub(".*class[=]'p-s'>(.+),\\s.*",
+          temp_opus[tf_opus] <- gsub(".*class=['\"]p-s['\"]>([^<]+).*",
                                      "\\1", temp_opus[tf_opus])
+          # temp_opus[tf_opus] <- gsub(".*class[=]'p-s'>(.+),\\s.*",
+          #                            "\\1", temp_opus[tf_opus])
         }
         tf_opus <- grepl("unknown\\spublication$|ipni[.]org", temp_opus)
         if(any(tf)) {
@@ -406,12 +408,22 @@ country_filter <- function(df,
                strsplit(df$native_to_country[i], ",")[[1]]) %in% country
     if (any(tt)) {
       temp[i] <- TRUE
+
     } else {
       temp[i] <- FALSE
     }
 
   }
 
+  for (i in seq_along(df$introduced_to_country)) {
+    tt <- gsub("^\\s", "",
+               strsplit(df$introduced_to_country[i], ",")[[1]]) %in% country
+    if (any(tt)) {
+      temp[i] <- TRUE
+    }
+
+  }
+
   # The following conditions is just to show/print how the df will be
   # subsetted according to the provided country vector.
   if (verbose) {
@@ -498,3 +510,4 @@ country_filter <- function(df,
   x[unlist(temp)] <- NA
   return(x)
 }
+
