@@ -1,3 +1,3 @@
 utils::globalVariables(c("POWOcodes", "botregions", "botdivmap", ".env", "year",
                          "year_basionym", "number_synonyms", "status",
-                         "..count..", ".data"))
+                         "setNames", "..count..", "na.omit", ".data"))
